EDGAR Filing Documents for 0000320193-19-000119

Search the Next-Generation EDGAR System
Filing Detail
Form 10-K - Annual report [Section 13 and 15(d), not S-K Item 405]:
SEC Accession No. 0000320193-19-000119
Filing Date
2019-10-31
Accepted
2019-10-30 18:12:36
Documents
96
Period of Report
2019-09-28
Interactive Data

Document Format Files

Seq | Description | Document | Type | Size
--- | --- | --- | --- | ---
1 | 10-K | a10-k20199282019.htm iXBRL | 10-K | 2714096
2 | EXHIBIT 4.1 | a10-kexhibit412019.htm | EX-4.1 | 140694
3 | EXHIBIT 10.15 | a10-kexhibit10152019.htm | EX-10.15 | 50665
4 | EXHIBIT 10.16 | a10-kexhibit10162019.htm | EX-10.16 | 68558
5 | EXHIBIT 21.1 | a10-kexhibit2112019.htm | EX-21.1 | 10756
6 | EXHIBIT 23.1 | a10-kexhibit2312019.htm | EX-23.1 | 8071
7 | EXHIBIT 31.1 | a10-kexhibit3112019.htm | EX-31.1 | 15675
8 | EXHIBIT 31.2 | a10-kexhibit3122019.htm | EX-31.2 | 15711
9 | EXHIBIT 32.1 | a10-kexhibit3212019.htm | EX-32.1 | 15195
15 |  | chart-06f17b4ddd9352dc8dc.jpg | GRAPHIC | 79662
16 |  | g66145g66i38.jpg | GRAPHIC | 10963
| Complete submission text file | 0000320193-19-000119.txt |  | 12861616

Data Files

Seq | Description | Document | Type | Size
--- | --- | --- | --- | ---
10 | XBRL TAXONOMY EXTENSION SCHEMA DOCUMENT | aapl-20190928.xsd | EX-101.SCH | 56071
11 | XBRL TAXONOMY EXTENSION CALCULATION LINKBASE DOCUMENT | aapl-20190928_cal.xml | EX-101.CAL | 123668
12 | XBRL TAXONOMY EXTENSION DEFINITION LINKBASE DOCUMENT | aapl-20190928_def.xml | EX-101.DEF | 306363
13 | XBRL TAXONOMY EXTENSION LABEL LINKBASE DOCUMENT | aapl-20190928_lab.xml | EX-101.LAB | 878875
14 | XBRL TAXONOMY EXTENSION PRESENTATION LINKBASE DOCUMENT | aapl-20190928_pre.xml | EX-101.PRE | 520951
67 | EXTRACTED XBRL INSTANCE DOCUMENT | a10-k20199282019_htm.xml | XML | 2774010

Mailing Address ONE APPLE PARK WAY CUPERTINO CA 95014
Business Address ONE APPLE PARK WAY CUPERTINO CA 95014 (408) 996-1010
Apple Inc. (Filer) CIK: 0000320193 (see all company filings)

IRS No.: 942404110 | State of Incorp.: CA | Fiscal Year End: 0928
Type: 10-K | Act: 34 | File No.: 001-36743 | Film No.: 191181423
SIC: 3571 Electronic Computers
Office of Technology